"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
function usePromise(promiseOrFn) {
    var _a = react_1.useState({
        loading: !!promiseOrFn,
        error: null,
        value: undefined
    }), state = _a[0], setState = _a[1];
    var isMounted = react_1.useRef(false);
    react_1.useEffect(function () {
        isMounted.current = true;
        if (!promiseOrFn) {
            setState({
                loading: false,
                error: null,
                value: undefined
            });
        }
        else {
            if (state.loading === false) {
                setState({
                    loading: true,
                    error: null,
                    value: undefined
                });
            }
            var promise = void 0;
            if (typeof promiseOrFn === 'function') {
                promise = promiseOrFn();
            }
            else {
                promise = promiseOrFn;
            }
            promise
                .then(function (value) {
                if (isMounted.current) {
                    setState({
                        loading: false,
                        error: null,
                        value: value
                    });
                }
            })
                .catch(function (error) {
                if (isMounted.current) {
                    setState({
                        loading: false,
                        error: error,
                        value: undefined
                    });
                }
            });
        }
        return function () {
            isMounted.current = false;
        };
    }, [promiseOrFn]);
    return state;
}
exports.default = usePromise;
//# sourceMappingURL=usePromise.js.map